@@ -1,12 +1,13 @@
 import hmac
 import json
-import requests
-from copy import deepcopy
 from base64 import b64encode
+from copy import deepcopy
 from hashlib import sha256
 from urllib.parse import urlencode
-from snaptrade.utils import SnapTradeUtils
+
+import requests
 from requests.exceptions import ConnectionError
+from snaptrade.utils import SnapTradeUtils
 
 
 class SnapTradeAPIClient:
@@ -35,9 +36,7 @@ class SnapTradeAPIClient:
 
         sig_content = json.dumps(sig_object, separators=(",", ":"), sort_keys=True)
 
-        sig_digest = hmac.new(
-            self.consumer_key.encode(), sig_content.encode(), sha256
-        ).digest()
+        sig_digest = hmac.new(self.consumer_key.encode(), sig_content.encode(), sha256).digest()
 
         signature = b64encode(sig_digest).decode()
 
@@ -78,9 +77,7 @@ class SnapTradeAPIClient:
 
         return prepared_params
 
-    def _make_request(
-        self, endpoint_name, data=None, path_params=None, query_params=None
-    ):
+    def _make_request(self, endpoint_name, data=None, path_params=None, query_params=None):
         if path_params is None:
             path_params = {}
 
@@ -98,26 +95,15 @@ class SnapTradeAPIClient:
 
         try:
             if method == "post":
-                response = requests.post(
-                    endpoint,
-                    headers=headers,
-                    params=query_params,
-                    json=data,
-                )
+                response = requests.post(endpoint, headers=headers, params=query_params, json=data)
             elif method == "get":
                 response = requests.get(endpoint, headers=headers, params=query_params)
             elif method == "put":
-                response = requests.put(
-                    endpoint, headers=headers, params=query_params, json=data
-                )
+                response = requests.put(endpoint, headers=headers, params=query_params, json=data)
             elif method == "delete":
-                response = requests.delete(
-                    endpoint, headers=headers, params=query_params, json=data
-                )
+                response = requests.delete(endpoint, headers=headers, params=query_params, json=data)
         except ConnectionError:
-            error_message = dict(
-                status_code=502, detail="Failed to connect to api server", code=0000
-            )
+            error_message = dict(status_code=502, detail="Failed to connect to api server", code=0000)
             if self.return_response_as_dict:
                 return error_message
             else:
@@ -175,34 +161,14 @@ class SnapTradeAPIClient:
 
         return self._make_request(endpoint_name, query_params=query_params)
 
-    def get_user_login_redirect_uri(
-        self,
-        user_id,
-        user_secret,
-        broker=None,
-        immediate_redirect=False,
-        custom_redirect=None,
-    ):
+    def get_user_login_redirect_uri(self, user_id, user_secret):
         """Returns redirect uri for user to"""
         endpoint_name = "user_login_redirect_uri"
 
         initial_query_params = dict(userId=user_id, userSecret=user_secret)
-        query_params = self.prepare_query_params(
-            endpoint_name, initial_params=initial_query_params
-        )
+        query_params = self.prepare_query_params(endpoint_name, initial_params=initial_query_params)
 
-        data = dict()
-        if broker:
-            data["broker"] = broker
-        if immediate_redirect:
-            data["immediateRedirect"] = True
-        if custom_redirect:
-            data["customRedirect"] = custom_redirect
-
-        if not data:
-            data = None
-
-        return self._make_request(endpoint_name, data=data, query_params=query_params)
+        return self._make_request(endpoint_name, query_params=query_params)
 
     """
     Accounts details, holdings, brokerage connection endpoints
@@ -212,107 +178,81 @@ class SnapTradeAPIClient:
         endpoint_name = "brokerage_authorizations"
 
         initial_query_params = dict(userId=user_id, userSecret=user_secret)
-        query_params = self.prepare_query_params(
-            endpoint_name, initial_params=initial_query_params
-        )
+        query_params = self.prepare_query_params(endpoint_name, initial_params=initial_query_params)
 
         return self._make_request(endpoint_name, query_params=query_params)
 
-    def get_brokerage_connection_by_id(
-        self, user_id, user_secret, brokerage_connection_id
-    ):
+    def get_brokerage_connection_by_id(self, user_id, user_secret, brokerage_connection_id):
         endpoint_name = "brokerage_authorization_by_id"
 
         initial_query_params = dict(userId=user_id, userSecret=user_secret)
-        query_params = self.prepare_query_params(
-            endpoint_name, initial_params=initial_query_params
-        )
+        query_params = self.prepare_query_params(endpoint_name, initial_params=initial_query_params)
 
         path_params = dict(brokerage_authorization_id=brokerage_connection_id)
 
-        return self._make_request(
-            endpoint_name, path_params=path_params, query_params=query_params
-        )
+        return self._make_request(endpoint_name, path_params=path_params, query_params=query_params)
 
-    def delete_brokerage_connection(
-        self, user_id, user_secret, brokerage_connection_id
-    ):
+    def delete_brokerage_connection(self, user_id, user_secret, brokerage_connection_id):
         endpoint_name = "delete_brokerage_authorization"
 
         initial_query_params = dict(userId=user_id, userSecret=user_secret)
-        query_params = self.prepare_query_params(
-            endpoint_name, initial_params=initial_query_params
-        )
+        query_params = self.prepare_query_params(endpoint_name, initial_params=initial_query_params)
 
         path_params = dict(brokerage_authorization_id=brokerage_connection_id)
 
-        return self._make_request(
-            endpoint_name, path_params=path_params, query_params=query_params
-        )
+        return self._make_request(endpoint_name, path_params=path_params, query_params=query_params)
 
     def get_accounts(self, user_id, user_secret):
         endpoint_name = "accounts"
         initial_query_params = dict(userId=user_id, userSecret=user_secret)
-        query_params = self.prepare_query_params(
-            endpoint_name, initial_params=initial_query_params
-        )
+        query_params = self.prepare_query_params(endpoint_name, initial_params=initial_query_params)
 
         return self._make_request(endpoint_name, query_params=query_params)
 
     def get_account_by_id(self, user_id, user_secret, account_id):
         endpoint_name = "account_details"
         initial_query_params = dict(userId=user_id, userSecret=user_secret)
-        query_params = self.prepare_query_params(
-            endpoint_name, initial_params=initial_query_params
-        )
+        query_params = self.prepare_query_params(endpoint_name, initial_params=initial_query_params)
         path_params = dict(account_id=account_id)
 
-        return self._make_request(
-            endpoint_name, path_params=path_params, query_params=query_params
-        )
+        return self._make_request(endpoint_name, path_params=path_params, query_params=query_params)
 
     def get_account_balances(self, user_id, user_secret, account_id):
         endpoint_name = "account_balances"
         initial_query_params = dict(userId=user_id, userSecret=user_secret)
-        query_params = self.prepare_query_params(
-            endpoint_name, initial_params=initial_query_params
-        )
+        query_params = self.prepare_query_params(endpoint_name, initial_params=initial_query_params)
         path_params = dict(account_id=account_id)
 
-        return self._make_request(
-            endpoint_name, path_params=path_params, query_params=query_params
-        )
+        return self._make_request(endpoint_name, path_params=path_params, query_params=query_params)
 
     def get_account_positions(self, user_id, user_secret, account_id):
         endpoint_name = "account_positions"
         initial_query_params = dict(userId=user_id, userSecret=user_secret)
-        query_params = self.prepare_query_params(
-            endpoint_name, initial_params=initial_query_params
-        )
+        query_params = self.prepare_query_params(endpoint_name, initial_params=initial_query_params)
         path_params = dict(account_id=account_id)
 
-        return self._make_request(
-            endpoint_name, path_params=path_params, query_params=query_params
-        )
+        return self._make_request(endpoint_name, path_params=path_params, query_params=query_params)
 
     def get_account_holdings(self, user_id, user_secret, account_id):
         endpoint_name = "account_holdings"
         initial_query_params = dict(userId=user_id, userSecret=user_secret)
-        query_params = self.prepare_query_params(
-            endpoint_name, initial_params=initial_query_params
-        )
+        query_params = self.prepare_query_params(endpoint_name, initial_params=initial_query_params)
         path_params = dict(account_id=account_id)
 
-        return self._make_request(
-            endpoint_name, path_params=path_params, query_params=query_params
-        )
+        return self._make_request(endpoint_name, path_params=path_params, query_params=query_params)
 
-    def get_all_holdings(self, user_id, user_secret):
+    def get_all_holdings(self, user_id, user_secret, brokerage_authorization_ids=None, account_numbers=None):
         endpoint_name = "holdings"
         initial_query_params = dict(userId=user_id, userSecret=user_secret)
-        query_params = self.prepare_query_params(
-            endpoint_name, initial_params=initial_query_params
-        )
+
+        if brokerage_authorization_ids:
+            brokerage_authorizations_ids_string = ",".join([str(auth_id) for auth_id in brokerage_authorization_ids])
+            initial_query_params["brokerage_authorizations"] = brokerage_authorizations_ids_string
+        if account_numbers:
+            accounts_numbers_string = ",".join([str(account_number) for account_number in account_numbers])
+            initial_query_params["accounts"] = accounts_numbers_string
+
+        query_params = self.prepare_query_params(endpoint_name, initial_params=initial_query_params)
 
         return self._make_request(endpoint_name, query_params=query_params)
 
@@ -331,42 +271,22 @@ class SnapTradeAPIClient:
         if end_date:
             initial_query_params["endDate"] = end_date
 
-        query_params = self.prepare_query_params(
-            endpoint_name, initial_params=initial_query_params
-        )
+        query_params = self.prepare_query_params(endpoint_name, initial_params=initial_query_params)
 
         return self._make_request(endpoint_name, query_params=query_params)
 
-    def get_performance_custom(
-        self,
-        user_id,
-        user_secret,
-        start_date,
-        end_date,
-        frequency=None,
-        account_ids=None,
-    ):
+    def get_performance_custom(self, user_id, user_secret, start_date, end_date, frequency=None, accountIDs=None):
         endpoint_name = "performance"
 
-        initial_query_params = dict(
-            userId=user_id,
-            userSecret=user_secret,
-            startDate=start_date,
-            end_date=end_date,
-        )
+        initial_query_params = dict(userId=user_id, userSecret=user_secret, startDate=start_date, end_date=end_date)
 
         if frequency:
             initial_query_params["frequency"] = frequency
 
-        if account_ids:  # Should be account IDs separated by commas
-            if type(account_ids) == list:
-                account_ids = ",".join(account_ids)
+        if accountIDs:  # Should be account IDs seprated by commas
+            initial_query_params["accounts"] = accountIDs
 
-            initial_query_params["accounts"] = account_ids
-
-        query_params = self.prepare_query_params(
-            endpoint_name, initial_params=initial_query_params
-        )
+        query_params = self.prepare_query_params(endpoint_name, initial_params=initial_query_params)
 
         return self._make_request(endpoint_name, query_params=query_params)
 
@@ -380,12 +300,6 @@ class SnapTradeAPIClient:
 
         return self._make_request(endpoint_name, query_params=query_params)
 
-    def get_exchanges(self):
-        endpoint_name = "exchanges"
-        query_params = self.prepare_query_params(endpoint_name)
-
-        return self._make_request(endpoint_name, query_params=query_params)
-
     def get_currencies(self):
         endpoint_name = "currencies"
         query_params = self.prepare_query_params(endpoint_name)
@@ -403,9 +317,7 @@ class SnapTradeAPIClient:
         query_params = self.prepare_query_params(endpoint_name)
         path_params = dict(currency_pair=f"{src_currency_code}-{dst_currency_code}")
 
-        return self._make_request(
-            endpoint_name, path_params=path_params, query_params=query_params
-        )
+        return self._make_request(endpoint_name, path_params=path_params, query_params=query_params)
 
     def search_symbols_by_name(self, substring):
         endpoint_name = "symbol_search"
@@ -419,26 +331,20 @@ class SnapTradeAPIClient:
         query_params = self.prepare_query_params(endpoint_name)
         path_params = dict(symbol_id=symbol_id)
 
-        return self._make_request(
-            endpoint_name, path_params=path_params, query_params=query_params
-        )
+        return self._make_request(endpoint_name, path_params=path_params, query_params=query_params)
 
     def get_symbol_details_by_ticker(self, ticker):
         endpoint_name = "symbol_by_ticker"
         query_params = self.prepare_query_params(endpoint_name)
         path_params = dict(ticker=ticker)
 
-        return self._make_request(
-            endpoint_name, path_params=path_params, query_params=query_params
-        )
+        return self._make_request(endpoint_name, path_params=path_params, query_params=query_params)
 
     """
     Trading endpoints
     """
 
-    def get_market_quotes(
-        self, user_id, user_secret, account_id, symbols, search_by_ticker=False
-    ):
+    def get_market_quotes(self, user_id, user_secret, account_id, symbols, search_by_ticker=False):
         endpoint_name = "symbol_quotes"
 
         symbols_string = ",".join(symbols)
@@ -452,13 +358,9 @@ class SnapTradeAPIClient:
         query_params = self.prepare_query_params(endpoint_name, initial_query_params)
         path_params = dict(account_id=account_id)
 
-        return self._make_request(
-            endpoint_name, path_params=path_params, query_params=query_params
-        )
+        return self._make_request(endpoint_name, path_params=path_params, query_params=query_params)
 
-    def get_account_order_history(
-        self, user_id, user_secret, account_id, state=None, days=None
-    ):
+    def get_account_order_history(self, user_id, user_secret, account_id, state=None, days=None):
         endpoint_name = "account_orders_history"
 
         initial_query_params = dict(userId=user_id, userSecret=user_secret)
@@ -469,14 +371,10 @@ class SnapTradeAPIClient:
         if days:
             initial_query_params["days"] = days
 
-        query_params = self.prepare_query_params(
-            endpoint_name, initial_params=initial_query_params
-        )
+        query_params = self.prepare_query_params(endpoint_name, initial_params=initial_query_params)
         path_params = dict(account_id=account_id)
 
-        return self._make_request(
-            endpoint_name, path_params=path_params, query_params=query_params
-        )
+        return self._make_request(endpoint_name, path_params=path_params, query_params=query_params)
 
     def get_trade_impact(
         self,
@@ -494,9 +392,7 @@ class SnapTradeAPIClient:
 
         initial_query_params = dict(userId=user_id, userSecret=user_secret)
 
-        query_params = self.prepare_query_params(
-            endpoint_name, initial_params=initial_query_params
-        )
+        query_params = self.prepare_query_params(endpoint_name, initial_params=initial_query_params)
 
         if time_in_force.title() == "Day":
             time_in_force = time_in_force.title()
@@ -511,38 +407,28 @@ class SnapTradeAPIClient:
             "units": units,
         }
 
-        return self._make_request(
-            endpoint_name, data=trade_data, query_params=query_params
-        )
+        return self._make_request(endpoint_name, data=trade_data, query_params=query_params)
 
     def place_order(self, user_id, user_secret, trade_id):
         endpoint_name = "place_order"
 
         initial_query_params = dict(userId=user_id, userSecret=user_secret)
 
-        query_params = self.prepare_query_params(
-            endpoint_name, initial_params=initial_query_params
-        )
+        query_params = self.prepare_query_params(endpoint_name, initial_params=initial_query_params)
 
         path_params = dict(trade_id=trade_id)
 
-        return self._make_request(
-            endpoint_name, path_params=path_params, query_params=query_params
-        )
+        return self._make_request(endpoint_name, path_params=path_params, query_params=query_params)
 
     def cancel_order(self, user_id, user_secret, account_id, brokerage_order_id):
         endpoint_name = "cancel_order"
 
         initial_query_params = dict(userId=user_id, userSecret=user_secret)
 
-        query_params = self.prepare_query_params(
-            endpoint_name, initial_params=initial_query_params
-        )
+        query_params = self.prepare_query_params(endpoint_name, initial_params=initial_query_params)
 
         path_params = dict(account_id=account_id)
 
         data = dict(brokerage_order_id=brokerage_order_id)
 
-        return self._make_request(
-            endpoint_name, path_params=path_params, query_params=query_params, data=data
-        )
+        return self._make_request(endpoint_name, path_params=path_params, query_params=query_params, data=data)
